package Bundle::MusicBrainz::Server;

use 5.008;

our $VERSION = '0.01';

1;
__END__

=head1 NAME

Bundle::MusicBrainz::Server - Bundle to install MusicBrainz server dependencies


=head1 SYNOPSIS

C<perl -MCPAN -e'install Bundle::MusicBrainz::Server'>


=head1 CONTENTS

Apache::Session
Apache::Session::File
Cache::Memcached
DBD::Pg
DBI
Digest::SHA1
HTML::Mason
HTTP::Negotiate
MIME-Base64
MIME::Lite
RDFStore
Storable
String::CRC32
UUID
Unicode::String
XML::Parser
Carp
IO::Socket
Net::SMTP
String::ShellQuote
Tie::STDERR
Time::HiRes
URI::Escape


=head1 AUTHOR

Matthias Friedrich, E<lt>matt@mafr.deE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2004 by Matthias Friedrich

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.0 or,
at your option, any later version of Perl 5 you may have available.

=cut
